summaryrefslogtreecommitdiffstats
path: root/src/projectfilesdlg.h
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2013-10-08 00:13:25 +0200
committerSlávek Banko <slavek.banko@axis.cz>2013-10-08 05:14:53 +0200
commit84f5a315c3429b47a7eff15e626e2efdbe4f6e5e (patch)
tree770861aa9033e1dc6c5168358194ff85b32dd429 /src/projectfilesdlg.h
parent57d8bb3d12aed373eee08915f0ff19f5233aabe3 (diff)
downloadkscope-84f5a315c3429b47a7eff15e626e2efdbe4f6e5e.tar.gz
kscope-84f5a315c3429b47a7eff15e626e2efdbe4f6e5e.zip
Initial TQt conversion
Diffstat (limited to 'src/projectfilesdlg.h')
-rw-r--r--src/projectfilesdlg.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/projectfilesdlg.h b/src/projectfilesdlg.h
index 9c6d791..abd86ef 100644
--- a/src/projectfilesdlg.h
+++ b/src/projectfilesdlg.h
@@ -28,9 +28,9 @@
#ifndef PROJECTFILESDLG_H
#define PROJECTFILESDLG_H
-#include <qwidget.h>
+#include <ntqwidget.h>
#include <projectfileslayout.h>
-#include <qdict.h>
+#include <ntqdict.h>
#include "project.h"
class DirScanner;
@@ -44,7 +44,7 @@ class ScanProgressDlg;
* removed, this list view is updated. The project, however, is only modified
* if the user closes the dialog using the "OK" button.
* Since searches through a list view are very slow, the class also maintains
* a QDict object, that connects file names with their respective list items.
* This dictionary is used to ensure duplicated items are not added to the
* list.
* @author Elad Lahav
@@ -56,15 +56,15 @@ class ProjectFilesDlg : public ProjectFilesLayout, public FileListTarget,
Q_OBJECT
public:
- ProjectFilesDlg(Project*, QWidget* pParent = 0, const char* szName = 0);
+ ProjectFilesDlg(Project*, TQWidget* pParent = 0, const char* szName = 0);
~ProjectFilesDlg();
- virtual void addItem(const QString&);
- virtual bool firstItem(QString&);
- virtual bool nextItem(QString&);
+ virtual void addItem(const TQString&);
+ virtual bool firstItem(TQString&);
+ virtual bool nextItem(TQString&);
protected:
- virtual void customEvent(QCustomEvent*);
+ virtual void customEvent(TQCustomEvent*);
private:
/** The project to manipulate. */
@@ -72,7 +72,7 @@ private:
/** Holds all file paths in a quickly searchable format (for duplicate
entries lookup). */
- QDict<QListViewItem> m_dicFiles;
+ TQDict<TQListViewItem> m_dicFiles;
/** A thread object to a-synchronously scan directories for source files
to add to the project. */
@@ -82,12 +82,12 @@ private:
ScanProgressDlg* m_pScanDlg;
/** A file list item that serves as an iterator. */
- QListViewItem* m_pItrItem;
+ TQListViewItem* m_pItrItem;
/** The last item added. */
- QListViewItem* m_pLastItem;
+ TQListViewItem* m_pLastItem;
- void removeItem(QListViewItem*);
+ void removeItem(TQListViewItem*);
private slots:
void slotAddFiles();
@@ -44,7 +44,7 @@ class ScanProgressDlg;
* if the user closes the dialog using the "OK" button.
* Since searches through a list view are very slow, the class also maintains
- * a QDict object, that connects file names with their respective list items.
+ * a TQDict object, that connects file names with their respective list items.
* This dictionary is used to ensure duplicated items are not added to the
* list.